import Layout from "./components/Layout";
// import Viewer from "./components/Viewer";
import Patients from "./components/fileSelectors/Patients";
import { useState, useEffect } from "react";
import Viewer from "./components/Viewer";
import SettingsModal from "./components/SettingsModal";
import PropTypes from "prop-types";

function App() {
  const DEBUG = false;
  const [patients, setPatients] = useState(null);
  const [currentPatient, setCurrentPatient] = useState(null);
  const [studies, setStudies] = useState([]);
  const [currentStudy, setCurrentStudy] = useState(null);
  const [series, setSeries] = useState([]);
  const [currentSeriesLeft, setCurrentSeriesLeft] = useState([]);
  const [currentSeriesRight, setCurrentSeriesRight] = useState([]);
  const [imageSeriesLeft, setImageSeriesLeft] = useState([]);
  const [currentSeriesIdLeft, setCurrentSeriesIdLeft] = useState("");
  const [currentSeriesIdRight, setCurrentSeriesIdRight] = useState("");
  const [open, setOpen] = useState(false);
  const [splitWindow, setSplitWindow] = useState(false);
  const [inverted, setInverted] = useState(false);
  const [colormapLeft, setColormapLeft] = useState("");
  const [colormapRight, setColormapRight] = useState("");
  const [opacity, setOpacity] = useState("100");
  const [currentFilter, setCurrentFilter] = useState("");
  const [sync, setSync] = useState(false);

  // use effects that print every state on state change
  useEffect(() => {
    if (DEBUG) {
      console.log("patients: ", patients);
      console.log("currentPatient: ", currentPatient);
      console.log("studies: ", studies);
      console.log("currentStudy: ", currentStudy);
      console.log("series: ", series);
      console.log("currentSeriesID: ", currentSeriesLeft);
      console.log("imageSeriesLeft: ", imageSeriesLeft);
    }
  }, [
    patients,
    currentPatient,
    studies,
    currentStudy,
    series,
    currentSeriesLeft,
    imageSeriesLeft,
    DEBUG,
  ]);

  return (
    <Layout>
      <div className="w-full flex-col h-92.5">
        <div className="w-full max-h-12 h-12 bg-gray-500 text-white text-xl pb-2">
          <SettingsModal
            open={open}
            setOpen={setOpen}
            patients={patients}
            setSeries={setSeries}
            currentPatient={currentPatient}
            setPatients={setPatients}
            setCurrentPatient={setCurrentPatient}
            setAvailableStudies={setStudies}
            studies={studies}
            setStudies={setStudies}
            currentStudy={currentStudy}
            setCurrentStudy={setCurrentStudy}
            series={series}
            setImageSeries={setImageSeriesLeft}
            setImageSeriesLeft={setImageSeriesLeft}
            setCurrentSeriesLeft={setCurrentSeriesLeft}
            setCurrentSeriesRight={setCurrentSeriesRight}
            splitWindow={splitWindow}
            setSplitWindow={setSplitWindow}
            inverted={inverted}
            setInverted={setInverted}
            currentSeriesIdLeft={currentSeriesIdLeft}
            setCurrentSeriesIdLeft={setCurrentSeriesIdLeft}
            currentSeriesIdRight={currentSeriesIdRight}
            setCurrentSeriesIdRight={setCurrentSeriesIdRight}
            colormapLeft={colormapLeft}
            setColormapLeft={setColormapLeft}
            colormapRight={colormapRight}
            setColormapRight={setColormapRight}
            setOpacity={setOpacity}
            opacity={opacity}
            currentFilter={currentFilter}
            setCurrentFilter={setCurrentFilter}
            setSync={setSync}
            sync={sync}
            imageIndexLeft={imageSeriesLeft}
          />
        </div>
        {currentSeriesLeft.length >= 1 && currentSeriesRight.length >= 1 ? (
          <Viewer
            imageSeriesLeft={currentSeriesLeft}
            imageSeriesRight={currentSeriesRight}
            splitWindow={splitWindow}
            colormapLeft={colormapLeft}
            colormapRight={colormapRight}
            inverted={inverted}
            opacity={opacity}
            currentFilter={currentFilter}
            sync={sync}
          />
        ) : (
          <div className="flex flex-row w-96">
            <Patients
              patients={patients}
              setSeries={setSeries}
              currentPatient={currentPatient}
              setOpen={setOpen}
              setPatients={setPatients}
              setCurrentPatient={setCurrentPatient}
              setAvailableStudies={setStudies}
            />
          </div>
        )}
      </div>
    </Layout>
  );
}

App.propTypes = {
  patients: PropTypes.array,
  currentPatient: PropTypes.object,
  studies: PropTypes.array,
  currentStudy: PropTypes.object,
  series: PropTypes.array,
  currentSeriesLeft: PropTypes.array,
  currentSeriesRight: PropTypes.array,
  imageSeriesLeft: PropTypes.array,
  currentSeriesIdLeft: PropTypes.string,
  currentSeriesIdRight: PropTypes.string,
  open: PropTypes.bool,
  splitWindow: PropTypes.bool,
  inverted: PropTypes.bool,
  colormapLeft: PropTypes.string,
  colormapRight: PropTypes.string,
  setPatients: PropTypes.func,
  setCurrentPatient: PropTypes.func,
  setStudies: PropTypes.func,
  setCurrentStudy: PropTypes.func,
  setSeries: PropTypes.func,
  setCurrentSeriesLeft: PropTypes.func,
  setCurrentSeriesRight: PropTypes.func,
  setImageSeriesLeft: PropTypes.func,
  setCurrentSeriesIdLeft: PropTypes.func,
  setCurrentSeriesIdRight: PropTypes.func,
  setOpen: PropTypes.func,
  setSplitWindow: PropTypes.func,
  setInverted: PropTypes.func,
  setColormapLeft: PropTypes.func,
  setColormapRight: PropTypes.func,
  setOpacity: PropTypes.func,
  opacity: PropTypes.string,
  currentFilter: PropTypes.string,
  setCurrentFilter: PropTypes.func,
};

export default App;
