import { Fragment } from "react";
import { Dialog, Transition } from "@headlessui/react";
import Studies from "./fileSelectors/Studies";
import Series from "./fileSelectors/Series";
import PropTypes from "prop-types";
import CssFilterSelector from "../helpers/cssFilterSelector";

function SettingsModal({
  open,
  setOpen,
  patients,
  setSeries,
  currentPatient,
  setPatients,
  setCurrentPatient,
  setAvailableStudies,
  studies,
  setStudies,
  currentStudy,
  setCurrentStudy,
  series,
  setImageSeries,
  setImageSeriesLeft,
  setCurrentSeriesLeft,
  setCurrentSeriesRight,
  splitWindow,
  setSplitWindow,
  inverted,
  setInverted,
  currentSeriesIdLeft,
  setCurrentSeriesIdLeft,
  currentSeriesIdRight,
  setCurrentSeriesIdRight,
  colormapLeft,
  setColormapLeft,
  colormapRight,
  setColormapRight,
  setOpacity,
  opacity,
  currentFilter,
  setCurrentFilter,
  setSync,
  sync,
}) {
  function handleChange(event) {
    const value = event.target.value;
    setOpacity(value);
  }

  return (
    <div className="">
      <div className="mx-10 flex space-x-10 pt-2">
        Opacity
        <div class="ml-2 relative">
          <input
            type="range"
            className="form-range appearance-none w-full h-2"
            defaultValue={opacity}
            min="0"
            max="100"
            step="10"
            onChange={(e) => handleChange(e)}
          />
        </div>
        <CssFilterSelector
          currentFilter={currentFilter}
          setCurrentFilter={setCurrentFilter}
        />
        <button onClick={() => setOpen(!open)}>Image Series</button>
        <button
          className="text-white"
          onClick={() => setSplitWindow(!splitWindow)}
        >
          Split/Double views
        </button>
        <button className="text-white" onClick={() => setInverted(!inverted)}>
          Invert colors
        </button>
        <button
          className={`${sync ? "text-green-500" : "text-white"}`}
          onClick={() => setSync(!sync)}
        >
          {sync ? "Sync: ON" : "Sync: OFF"}
        </button>
      </div>
      <Transition.Root show={open} as={Fragment}>
        <Dialog
          as="div"
          className="fixed z-10 inset-0 overflow-y-auto"
          onClose={setOpen}
        >
          <div className="flex items-end justify-center min-h-screen pt-4 px-4 pb-20 text-center sm:block sm:p-0">
            <Transition.Child
              as={Fragment}
              enter="ease-out duration-300"
              enterFrom="opacity-0"
              enterTo="opacity-100"
              leave="ease-in duration-200"
              leaveFrom="opacity-100"
              leaveTo="opacity-0"
            >
              <Dialog.Overlay className="fixed inset-0 bg-gray-500 bg-opacity-75 transition-opacity" />
            </Transition.Child>

            {/* This element is to trick the browser into centering the modal contents. */}
            <span
              className="hidden sm:inline-block sm:align-middle sm:h-screen"
              aria-hidden="true"
            >
              &#8203;
            </span>
            <Transition.Child
              as={Fragment}
              enter="ease-out duration-300"
              enterFrom="opacity-0 translate-y-4 sm:translate-y-0 sm:scale-95"
              enterTo="opacity-100 translate-y-0 sm:scale-100"
              leave="ease-in duration-200"
              leaveFrom="opacity-100 translate-y-0 sm:scale-100"
              leaveTo="opacity-0 translate-y-4 sm:translate-y-0 sm:scale-95"
            >
              <div className="relative inline-block align-bottom bg-white rounded-lg text-left overflow-hidden transform transition-all w-5/6 bg-transparent">
                <div>
                  <div className="text-center sm:mt-5">
                    {currentPatient ? (
                      <Studies
                        studies={studies}
                        setStudies={setStudies}
                        setSeries={setSeries}
                        currentStudy={currentStudy}
                        setCurrentStudy={setCurrentStudy}
                      />
                    ) : (
                      <p className="text-white">Please select a patient</p>
                    )}
                    {series ? (
                      <Series
                        series={series}
                        setImageSeries={setImageSeriesLeft}
                        setCurrentSeriesLeft={setCurrentSeriesLeft}
                        setCurrentSeriesRight={setCurrentSeriesRight}
                        currentSeriesIdLeft={currentSeriesIdLeft}
                        setCurrentSeriesIdLeft={setCurrentSeriesIdLeft}
                        currentSeriesIdRight={currentSeriesIdRight}
                        setCurrentSeriesIdRight={setCurrentSeriesIdRight}
                        colormapLeft={colormapLeft}
                        setColormapLeft={setColormapLeft}
                        colormapRight={colormapRight}
                        setColormapRight={setColormapRight}
                      />
                    ) : (
                      <p className="text-white">Please select a study</p>
                    )}
                    <div className="mt-2"></div>
                  </div>
                </div>
                <div className="mt-5 sm:mt-6">
                  <button
                    type="button"
                    className="inline-flex justify-center w-full rounded-md border-2 border-slate-400 shadow-sm px-4 py-2 bg-slate-600 text-base font-medium text-white hover:bg-slate-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 sm:text-sm"
                    onClick={() => setOpen(false)}
                  >
                    Close
                  </button>
                </div>
              </div>
            </Transition.Child>
          </div>
        </Dialog>
      </Transition.Root>
    </div>
  );
}

SettingsModal.propTypes = {
  open: PropTypes.bool.isRequired,
  setOpen: PropTypes.func.isRequired,
  patients: PropTypes.array.isRequired,
  setSeries: PropTypes.func.isRequired,
  currentPatient: PropTypes.string.isRequired,
  setPatients: PropTypes.func.isRequired,
  setCurrentPatient: PropTypes.func.isRequired,
  setAvailableStudies: PropTypes.func.isRequired,
  studies: PropTypes.array.isRequired,
  setStudies: PropTypes.func.isRequired,
  currentStudy: PropTypes.string.isRequired,
  setCurrentStudy: PropTypes.func.isRequired,
  series: PropTypes.array.isRequired,
  setImageSeries: PropTypes.func.isRequired,
  setImageSeriesLeft: PropTypes.func.isRequired,
  setCurrentSeriesLeft: PropTypes.func.isRequired,
  setCurrentSeriesRight: PropTypes.func.isRequired,
  splitWindow: PropTypes.bool.isRequired,
  setSplitWindow: PropTypes.func.isRequired,
  inverted: PropTypes.bool.isRequired,
  setInverted: PropTypes.func.isRequired,
  currentSeriesIdLeft: PropTypes.string.isRequired,
  setCurrentSeriesIdLeft: PropTypes.func.isRequired,
  currentSeriesIdRight: PropTypes.string.isRequired,
  setCurrentSeriesIdRight: PropTypes.func.isRequired,
  colormapLeft: PropTypes.string.isRequired,
  setColormapLeft: PropTypes.func.isRequired,
  colormapRight: PropTypes.string.isRequired,
  setColormapRight: PropTypes.func.isRequired,
  opacity: PropTypes.string.isRequired,
  setOpacity: PropTypes.func.isRequired,
  currentFilter: PropTypes.string.isRequired,
  setCurrentFilter: PropTypes.func.isRequired,
  setSync: PropTypes.func.isRequired,
  sync: PropTypes.bool.isRequired,
};

export default SettingsModal;
