import { useState, useEffect } from "react";
import { getPatientInfo } from "../../helpers/calls";

export default function PatientCard({
  patient,
  currentPatient,
  setOpen,
  setPatient,
  setStudies,
}) {
  const [loading, setLoading] = useState(true);
  const [patientInfo, setPatientInfo] = useState({});
  const [setError] = useState(null);

  function handleClick(patient, studies) {
    setPatient(patient);
    setStudies(studies);
    setOpen(true);
  }
  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await getPatientInfo(patient);
        setPatientInfo(response);
      } catch (error) {
        setError(error);
        console.error(error);
      }
      setLoading(false);
    };
    fetchData();
  }, [currentPatient, patient, setError]);

  return (
    <div className="cursor-pointer">
      {loading ? (
        <p>Loading...</p>
      ) : (
        <div
          className="p-2 text-black shadow-lg m-2"
          onClick={() => handleClick(patientInfo.ID, patientInfo.Studies)}
        >
          <table className="table-auto leading-normal rounded-2xl">
            <thead>
              <tr>
                <th className="rounded-tl-xl px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-center text-xs font-semibold text-gray-600 uppercase tracking-wider w-48">
                  Patient ID
                </th>
                <th className="rounded-tr-xl px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-center text-xs font-semibold text-gray-600 uppercase tracking-wider w-48">
                  Patient name
                </th>
              </tr>
            </thead>
            <tbody className="rounded-b-xl text-center border-b border-gray-200 bg-white text-sm">
              <tr>
                <td>{patientInfo.MainDicomTags.PatientID}</td>
                <td>{patientInfo.MainDicomTags.PatientName}</td>
              </tr>
            </tbody>
          </table>
        </div>
      )}
    </div>
  );
}
