import { useEffect, useState } from "react";
import PatientCard from "./PatientCard";
import { PATIENTS } from "../../helpers/calls";

export default function Patients({
  patients,
  setSeries,
  currentPatient,
  setOpen,
  setPatients,
  setCurrentPatient,
  setAvailableStudies,
}) {
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await fetch(PATIENTS);
        const patients = await response.json();
        setPatients(patients);
      } catch (error) {
        setError(error);
      }
      setLoading(false);
    };
    setSeries(null);
    fetchData();
  }, [currentPatient]);

  if (error) {
    return (
      <p className="text-white">
        Error: {error.message} with call to {PATIENTS}
      </p>
    );
  }

  if (loading) {
    return <p className="text-white">Loading...</p>;
  } else {
    return (
      <div className="text-white w-96">
        {patients.map((patient, idx) => (
          <PatientCard
            key={idx}
            patient={patient}
            currentPatient={currentPatient}
            setPatient={setCurrentPatient}
            setStudies={setAvailableStudies}
            setOpen={setOpen}
          />
        ))}
      </div>
    );
  }
}
