import { useEffect, useState } from "react";
import { getSeriesInfo } from "../../helpers/calls";
import ColormapSelector from "../viewHelpers/colorMapSelector";
import PropTypes from "prop-types";

function SeriesCard({
  series,
  setCurrentSeriesLeft,
  setCurrentSeriesRight,
  currentSeriesIdLeft,
  setCurrentSeriesIdLeft,
  currentSeriesIdRight,
  setCurrentSeriesIdRight,
  colormapLeft,
  setColormapLeft,
  colormapRight,
  setColormapRight,
}) {
  const [loading, setLoading] = useState(true);
  const [seriesInfo, setSeriesInfo] = useState([]);

  function handleClickLeft(seriesId, imageSeries) {
    setCurrentSeriesLeft(imageSeries);
    setCurrentSeriesIdLeft(seriesId);
  }

  function handleClickRight(seriesId, imageSeries) {
    setCurrentSeriesRight(imageSeries);
    setCurrentSeriesIdRight(seriesId);
  }

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await getSeriesInfo(series);
        setSeriesInfo(response);
      } catch (error) {
        console.error(error);
      }
      setLoading(false);
    };
    fetchData();
  }, [series, currentSeriesIdLeft, currentSeriesIdRight]);

  return (
    <div className="max-w-48 min-h-24">
      {loading ? (
        <p className="text-white">Loading...</p>
      ) : seriesInfo.Instances.length > 4 ? (
        <div className="p-2 bg-slate-300 border-2 border-slate-400 text-black shadow-lg rounded-lg m-2 max-w-48">
          <table className="table-auto min-w-full leading-normal">
            <thead>
              <tr>
                <th className="rounded-tl-xl px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                  Type
                </th>
                <th className="rounded-tr-xl px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                  Value
                </th>
              </tr>
            </thead>
            <tbody className="px-5 py-5 border-b border-gray-200 bg-white text-sm text-left">
              {/* <tr>
                  <td>Series ID</td>
                  <td>{seriesInfo.ID}</td>
                </tr> */}
              <tr>
                <td>Series Description</td>
                <td>{seriesInfo.MainDicomTags.SeriesDescription}</td>
              </tr>
              <tr
                className={`${
                  seriesInfo.MainDicomTags.Modality === "CT"
                    ? "bg-green-200"
                    : seriesInfo.MainDicomTags.Modality === "PT"
                    ? "bg-cyan-200"
                    : "bg-red-200"
                }`}
              >
                <td>Modality</td>
                <td>{seriesInfo.MainDicomTags.Modality}</td>
              </tr>
              {/* <tr>
                  <td>Series Date</td>
                  <td>{convertToDate(seriesInfo.MainDicomTags.SeriesDate)}</td>
                </tr> */}
              {/*<tr>
                   <td>Series Direction</td>
                  <td>
                    {seriesInfo.MainDicomTags.ImageOrientationPatient[0] > 0
                      ? "Right"
                      : "Left"}
                  </td> 
                </tr>*/}
              <tr>
                <td>Number of images</td>
                <td>{seriesInfo.Instances.length}</td>
              </tr>
              <tr>
                <td>Protocol Name</td>
                <td>{seriesInfo.MainDicomTags.ProtocolName}</td>
              </tr>
            </tbody>
          </table>
          <div className="pt-2">
            <div className="flex flex-row w-full justify-around">
              <ColormapSelector
                colormap={colormapLeft}
                setColormap={setColormapLeft}
              />
              <button
                className={`${
                  seriesInfo.ID === currentSeriesIdLeft
                    ? "bg-slate-400 text-white"
                    : "bg-white text-black"
                } border-2 border-gray-100 rounded-xl p-2 mx-2 w-20`}
                onClick={() =>
                  handleClickLeft(seriesInfo.ID, seriesInfo.Instances)
                }
              >
                Set left
              </button>
              <button
                className={`${
                  seriesInfo.ID === currentSeriesIdRight
                    ? "bg-slate-400 text-white"
                    : "bg-white text-black"
                } border-2 border-gray-100 rounded-xl p-2 mx-2 w-20`}
                onClick={() =>
                  handleClickRight(seriesInfo.ID, seriesInfo.Instances)
                }
              >
                Set right
              </button>
              <ColormapSelector
                colormap={colormapRight}
                setColormap={setColormapRight}
              />
            </div>
          </div>
        </div>
      ) : (
        <div className="p-2 bg-red-300 border-2 border-slate-400 text-black shadow-lg rounded-lg m-2 max-w-48">
          <table className="table-auto min-w-full leading-normal">
            <thead>
              <tr>
                <th className="rounded-tl-xl px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                  Type
                </th>
                <th className="rounded-tr-xl px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-left text-xs font-semibold text-gray-600 uppercase tracking-wider">
                  Value
                </th>
              </tr>
            </thead>
            <tbody className="px-5 py-5 border-b border-gray-200 bg-white text-sm text-left">
              <tr>
                <td>Series Description</td>
                <td>{seriesInfo.MainDicomTags.SeriesDescription}</td>
              </tr>
              <tr
                className={`${
                  seriesInfo.MainDicomTags.Modality === "CT"
                    ? "bg-green-200"
                    : seriesInfo.MainDicomTags.Modality === "PT"
                    ? "bg-cyan-200"
                    : "bg-red-200"
                }`}
              >
                <td>Modality</td>
                <td>{seriesInfo.MainDicomTags.Modality}</td>
              </tr>
              <tr>
                <td>Number of images</td>
                <td>{seriesInfo.Instances.length}</td>
              </tr>
              <tr>
                <td>Protocol Name</td>
                <td>{seriesInfo.MainDicomTags.ProtocolName}</td>
              </tr>
            </tbody>
          </table>
          <div className="pt-2">
            <div className="flex flex-row w-full justify-around">
              <ColormapSelector
                colormap={colormapLeft}
                setColormap={setColormapLeft}
              />
              <button
                className={`${
                  seriesInfo.ID === currentSeriesIdLeft
                    ? "bg-slate-400 text-white"
                    : "bg-white text-black"
                } border-2 border-gray-100 rounded-xl p-2 mx-2 w-20`}
                onClick={() =>
                  handleClickLeft(seriesInfo.ID, seriesInfo.Instances)
                }
              >
                Set left
              </button>
              <button
                className={`${
                  seriesInfo.ID === currentSeriesIdRight
                    ? "bg-slate-400 text-white"
                    : "bg-white text-black"
                } border-2 border-gray-100 rounded-xl p-2 mx-2 w-20`}
                onClick={() =>
                  handleClickRight(seriesInfo.ID, seriesInfo.Instances)
                }
              >
                Set right
              </button>
              <ColormapSelector
                colormap={colormapRight}
                setColormap={setColormapRight}
              />
            </div>
          </div>
        </div>
      )}
    </div>
  );
}

SeriesCard.propTypes = {
  series: PropTypes.string.isRequired,
  setCurrentSeriesLeft: PropTypes.func.isRequired,
  setCurrentSeriesRight: PropTypes.func.isRequired,
  currentSeriesIdLeft: PropTypes.string.isRequired,
  setCurrentSeriesIdLeft: PropTypes.func.isRequired,
  currentSeriesIdRight: PropTypes.string.isRequired,
  setCurrentSeriesIdRight: PropTypes.func.isRequired,
  colormapLeft: PropTypes.string.isRequired,
  setColormapLeft: PropTypes.func.isRequired,
  colormapRight: PropTypes.string.isRequired,
  setColormapRight: PropTypes.func.isRequired,
};

export default SeriesCard;
