import { useEffect, useState } from "react";
import { getStudyInfo } from "../../helpers/calls";
import { convertToDate } from "../../helpers/convertToDate";

export default function StudiesCard({
  study,
  currentStudy,
  setCurrentStudy,
  setSeries,
}) {
  const [loading, setLoading] = useState(true);
  const [studyInfo, setStudyInfo] = useState([]);

  function handleClick(study, series) {
    setCurrentStudy(study);
    setSeries(series);
  }

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await getStudyInfo(study);
        setStudyInfo(response);
      } catch (error) {
        console.error(error);
      }
      setLoading(false);
    };
    fetchData();
  }, [currentStudy, study]);

  return (
    <div className="max-w-48 min-h-24 cursor-pointer">
      {loading ? (
        <p className="text-white">Loading...</p>
      ) : (
        <div
          className="p-2 bg-slate-400 text-black shadow-lg rounded-lg m-2 max-w-48"
          onClick={() => handleClick(studyInfo.ID, studyInfo.Series)}
        >
          <table className="table-auto min-w-full leading-normal">
            <thead>
              <tr>
                <th className="rounded-tl-xl px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-center text-xs font-semibold text-gray-600 uppercase tracking-wider">
                  Study procedure
                </th>
                <th className="rounded-tr-xl px-5 py-3 border-b-2 border-gray-200 bg-gray-100 text-center text-xs font-semibold text-gray-600 uppercase tracking-wider">
                  Study date
                </th>
              </tr>
            </thead>
            <tbody className="px-5 py-5 border-b border-gray-200 bg-white text-sm text-center">
              <tr>
                <td>{studyInfo.MainDicomTags.RequestedProcedureDescription}</td>
                <td>{convertToDate(studyInfo.MainDicomTags.StudyDate)}</td>
              </tr>
            </tbody>
          </table>
        </div>
      )}
    </div>
  );
}
