import React, { useState } from "react";
import CornerstoneViewport from "react-cornerstone-viewport";
import cornerstone from "cornerstone-core";

export default function ViewportWrapper({
  formattedImageSeries,
  inverted,
  toolStates,
  colormap,
  splitWindow,
  opacity,
  currentFilter,
  imageIndex,
  setImageIndex,
}) {
  const [cornerstoneElement, setCornerstoneElement] = useState(null);

  return (
    <div
      className={`w-full h-full max-w-screen transition-all duration-300 mx-0 px-0 ${
        inverted ? "invert" : ""
      }`}
    >
      <CornerstoneViewport
        style={{
          opacity: `${opacity}%`,
          mixBlendMode: `${currentFilter}`,
          height: "100%",
          width: "100%",
        }}
        tools={toolStates}
        imageIds={formattedImageSeries}
        imageIdIndex={parseInt(imageIndex)}
        onElementEnabled={(elementEnabledEvt) => {
          const cornerstoneElement = elementEnabledEvt.detail.element;
          // Save this for later
          setCornerstoneElement({
            cornerstoneElement,
          });
          // Wait for image to render, then invert it
          cornerstoneElement.addEventListener(
            "cornerstoneimagerendered",
            (imageRenderedEvent) => {
              const viewport = imageRenderedEvent.detail.viewport;
              const invertedViewport = Object.assign({}, viewport, {
                colormap: colormap,
              });
              cornerstone.setViewport(cornerstoneElement, invertedViewport);
            }
          );
        }}
      />
    </div>
  );
}
